package com.agri.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.agri.system.domain.SysRollerAir;

/**
 * 自动化卷膜风口大小设置Service接口
 * 
 * @author lld
 * @date 2026-03-04
 */
public interface ISysRollerAirService  extends IService<SysRollerAir> {
    /**
     * 查询自动化卷膜风口大小设置
     * 
     * @param id 自动化卷膜风口大小设置主键
     * @return 自动化卷膜风口大小设置
     */
    public SysRollerAir selectSysRollerAirById(Long id);

    /**
     * 查询自动化卷膜风口大小设置列表
     * 
     * @param sysRollerAir 自动化卷膜风口大小设置
     * @return 自动化卷膜风口大小设置集合
     */
    public List<SysRollerAir> selectSysRollerAirList(SysRollerAir sysRollerAir);

    /**
     * 新增自动化卷膜风口大小设置
     * 
     * @param sysRollerAir 自动化卷膜风口大小设置
     * @return 结果
     */
    public int insertSysRollerAir(SysRollerAir sysRollerAir);

    /**
     * 修改自动化卷膜风口大小设置
     * 
     * @param sysRollerAir 自动化卷膜风口大小设置
     * @return 结果
     */
    public int updateSysRollerAir(SysRollerAir sysRollerAir);

    /**
     * 批量删除自动化卷膜风口大小设置
     * 
     * @param ids 需要删除的自动化卷膜风口大小设置主键集合
     * @return 结果
     */
    public int deleteSysRollerAirByIds(Long[] ids);

    /**
     * 删除自动化卷膜风口大小设置信息
     * 
     * @param id 自动化卷膜风口大小设置主键
     * @return 结果
     */
    public int deleteSysRollerAirById(Long id);
}
